searchData={"content_type":"text/markdown","items":[{"doc":"Implements a token-based rate limiter using the leaky bucket algorithm, ideal for controlling access rates to resources in Elixir applications.\nThis implementation leverages ETS for optimized performance, making it suitable for high-load environments.","ref":"Leaky.html","title":"Leaky","type":"module"},{"doc":"The leaky bucket algorithm helps smooth out bursty traffic by limiting the rate at which actions are taken.\nIt's like a bucket with a hole: tokens, representing permissions to take an action, drip out at a constant rate.\nIf the bucket is full, new actions must wait, ensuring the overall rate does not exceed the desired threshold.\nRead more about the algorithm here: https://en.wikipedia.org/wiki/Leaky_bucket","ref":"Leaky.html#module-overview","title":"Overview - Leaky","type":"module"},{"doc":"The rate limiter process can be customized with several options:\n- `bucket_name`: Unique identifier for the bucket.\n- `max_accumulated`: The maximum tokens the bucket can hold. Once full, new tokens will not accumulate.\n- `refill`: The number of tokens added to the bucket on each refill cycle.\n- `interval`: The time (in ms) between each refill cycle. Defaults to 1000 ms.\n- `name`: The GenServer process name. Defaults to `Leaky`.\n\n```elixir\n  configuration = [bucket_name: :user_requests, max_accumulated: 100, refill: 10, interval: 1000]\n  {:ok, _pid} = Leaky.start_link(configuration)\n```\n\nTo attempt an action, checking if it's allowed under the current rate:\n```elixir\n  case Leaky.acquire(:user_requests, 1) do\n    {:allow, tokens_left} -> \"Action allowed.\"\n    :deny ->\"Action denied.\"\n  end\n```","ref":"Leaky.html#module-usage","title":"Usage - Leaky","type":"module"},{"doc":"The function evaluates whether a particular action can proceed without violating the configured rate limit of the bucket.\nIt is designed to ensure that the frequency of actions does not exceed the predetermined limits, thus preventing system overload or abuse.","ref":"Leaky.html#acquire/3","title":"Leaky.acquire/3","type":"function"},{"doc":"```elixir\n.  case Leaky.acquire(:user_requests, 1) do\n    {:allow, tokens_left} -> \"Action allowed.\"\n    :deny ->\"Action denied.\"\n  end\n```","ref":"Leaky.html#acquire/3-examples","title":"Examples - Leaky.acquire/3","type":"function"},{"doc":"The function adjusts the number of tokens in a specified bucket by either adding (incrementing) or removing (decrementing) tokens,\ndirectly influencing the bucket's current capacity without performing a rate check.","ref":"Leaky.html#adjust_tokens/3","title":"Leaky.adjust_tokens/3","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Leaky.html#child_spec/1","title":"Leaky.child_spec/1","type":"function"},{"doc":"The function retrieves the current number of available tokens in the specified bucket,\nproviding insight into the bucket's current state without altering it.\nIt accepts the bucket identifier and an optional name parameter for the GenServer managing the rate limiter's state,\nreturning either the number of tokens left or nil if the bucket does not exist.\nThis function is useful for monitoring and debugging purposes, allowing developers to assess the rate limiter's status at any given moment.","ref":"Leaky.html#inspect/2","title":"Leaky.inspect/2","type":"function"},{"doc":"```\n iex> Leaky.inspect(:user_requests)\n iex> 3\n```","ref":"Leaky.html#inspect/2-example","title":"Example - Leaky.inspect/2","type":"function"},{"doc":"","ref":"Leaky.html#start_link/1","title":"Leaky.start_link/1","type":"function"},{"doc":"Updates the configuration of the rate limiter process. Changes are applied immediately, affecting the rate limiter's behavior.\nIt is useful for dynamically adjusting the rate limiter's settings without restarting the process.\n\nOptions which can be updated: `max_accumulated`, `interval`, and `refill`.","ref":"Leaky.html#update_configuration/2","title":"Leaky.update_configuration/2","type":"function"},{"doc":"```\niex> Leaky.update_configuration(max_accumulated: 10, refill: 2, interval: 5)\n:ok\niex> {:allow, 8} == Leaky.acquire(:user_requests, 2)\ntrue\n```","ref":"Leaky.html#update_configuration/2-example","title":"Example - Leaky.update_configuration/2","type":"function"},{"doc":"","ref":"Leaky.html#t:bucket/0","title":"Leaky.bucket/0","type":"type"},{"doc":"# Leaky\n\nImplements a token-based rate limiter using the leaky bucket algorithm, ideal for controlling access rates to resources in Elixir applications.\nThis implementation leverages ETS for optimized performance, making it suitable for high-load environments.","ref":"readme.html","title":"Leaky","type":"extras"},{"doc":"The leaky bucket algorithm helps smooth out bursty traffic by limiting the rate at which actions are taken.\nIt's like a bucket with a hole: tokens, representing permissions to take an action, drip out at a constant rate.\nIf the bucket is full, new actions must wait, ensuring the overall rate does not exceed the desired threshold.\nRead more about the algorithm here: https://en.wikipedia.org/wiki/Leaky_bucket","ref":"readme.html#overview","title":"Overview - Leaky","type":"extras"},{"doc":"Add the following to your `mix.exs` file:\n```elixir\n  def deps do\n  [\n    {:leaky, \"~> 0.1.0\"},\n  ]\nend\n```","ref":"readme.html#instalation","title":"Instalation - Leaky","type":"extras"},{"doc":"The rate limiter process can be customized with several options:\n- `bucket_name`: Unique identifier for the bucket.\n- `max_accumulated`: The maximum tokens the bucket can hold. Once full, new tokens will not accumulate.\n- `refill`: The number of tokens added to the bucket on each refill cycle.\n- `interval`: The time (in ms) between each refill cycle. Defaults to 1000 ms.\n- `name`: The GenServer process name. Defaults to `Leaky`.\n\n```elixir\n  configuration = [bucket_name: :user_requests, max_accumulated: 100, refill: 10, interval: 1000]\n  {:ok, _pid} = Leaky.start_link(configuration)\n```\n\nTo attempt an action, checking if it's allowed under the current rate:\n```elixir\n  case Leaky.acquire(:user_requests, 1) do\n    {:allow, tokens_left} -> \"Action allowed.\"\n    :deny ->\"Action denied.\"\n  end\n```","ref":"readme.html#usage","title":"Usage - Leaky","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}